aboutsummaryrefslogtreecommitdiffstats
path: root/tools
diff options
context:
space:
mode:
authorPascal Quantin <pascal@wireshark.org>2019-12-31 17:51:41 +0100
committerPascal Quantin <pascal@wireshark.org>2019-12-31 17:20:30 +0000
commitf8aa0d5c025d085212aa345a81f56dbace4c54c4 (patch)
treec5b2a73f8322690e92077755d6722cd053650101 /tools
parent6d5c7497853fed1e9f7210ca5a2f27f7dccfabb7 (diff)
LPP: upgrade dissector to 37.355 v15.0.0
3GPP decided to transfer the specification from 36.355 to 37.355 now that it covers NR also. 37.355 v15.0.0 is equivalent to 36.355 v15.5.0. Change-Id: I63aba21f55861ffd8a5c0adbd307b0453482baaa Reviewed-on: https://code.wireshark.org/review/35613 Petri-Dish: Pascal Quantin <pascal@wireshark.org> Tested-by: Petri Dish Buildbot Reviewed-by: Pascal Quantin <pascal@wireshark.org>
Diffstat (limited to 'tools')
-rwxr-xr-xtools/extract_asn1_from_spec.pl4
1 files changed, 2 insertions, 2 deletions
diff --git a/tools/extract_asn1_from_spec.pl b/tools/extract_asn1_from_spec.pl
index 8c69b55f6c..a2ec49be95 100755
--- a/tools/extract_asn1_from_spec.pl
+++ b/tools/extract_asn1_from_spec.pl
@@ -1,6 +1,6 @@
#!/usr/bin/perl
#
# This script extracts the ASN1 definition from and TS 36.331/36.355/25.331/38.331
# and generates asn files that can be processed by asn2wrs
# First download the specification from 3gpp.org as a word document and open it
# Then in "view" menu, select normal, draft or web layout (any kind that removes page header and footers)
@@ -35,7 +35,7 @@ close(INPUT_FILE);
sub extract_spec_version {
my $line;
while($line = <INPUT_FILE>){
- if($line =~ m/3GPP TS ((25|36|38)\.331|36\.355) V/){
+ if($line =~ m/3GPP TS ((25|36|38)\.331|(36|37)\.355) V/){
$version = $line;
return;
}
@@ -1,6 +1,6 @@
#!/usr/bin/perl
#
-# This script extracts the ASN1 definition from and TS 36.331/36.355/25.331/38.331
+# This script extracts the ASN1 definition from and TS 36.331/36.355/25.331/38.331/37.355
# and generates asn files that can be processed by asn2wrs
# First download the specification from 3gpp.org as a word document and open it